@@ -39,21 +39,23 @@
 #' plot(result, type = "qq", detrend = TRUE)
 #'
 #' @export
-plot.see_check_normality <- function(x,
-                                     type = c("qq", "pp", "density"),
-                                     data = NULL,
-                                     linewidth = 0.8,
-                                     size_point = 2,
-                                     size_title = 12,
-                                     size_axis_title = base_size,
-                                     base_size = 10,
-                                     alpha = 0.2,
-                                     alpha_dot = 0.8,
-                                     colors = c("#3aaf85", "#1b6ca8"),
-                                     detrend = TRUE,
-                                     method = "ell",
-                                     ...) {
-  type <- match.arg(type)
+plot.see_check_normality <- function(
+  x,
+  type = "qq",
+  data = NULL,
+  linewidth = 0.8,
+  size_point = 2,
+  size_title = 12,
+  size_axis_title = base_size,
+  base_size = 10,
+  alpha = 0.2,
+  alpha_dot = 0.8,
+  colors = c("#3aaf85", "#1b6ca8"),
+  detrend = TRUE,
+  method = "ell",
+  ...
+) {
+  type <- insight::validate_argument(type, c("qq", "pp", "density"))
 
   if (is.null(data)) {
     model <- .retrieve_data(x)
@@ -77,107 +79,149 @@ plot.see_check_normality <- function(x,
       size_title = size_title,
       base_size = base_size
     )
-  } else {
-    if (type == "qq") { # nolint
-      model_info <- attributes(x)$model_info
-      if (inherits(model, c("lme", "lmerMod", "merMod", "afex_aov", "BFBayesFactor"))) {
-        res_ <- suppressMessages(sort(stats::residuals(model), na.last = NA))
-        dat <- stats::na.omit(data.frame(y = res_))
-      } else if (inherits(model, "glmmTMB")) {
-        res_ <- abs(stats::residuals(model, type = "deviance"))
-        dat <- stats::na.omit(data.frame(y = res_))
-      } else if (inherits(model, "glm")) {
-        res_ <- abs(stats::rstandard(model, type = "deviance"))
-        fitted_ <- stats::qnorm((stats::ppoints(length(res_)) + 1) / 2)[order(order(res_))]
-        dat <- stats::na.omit(data.frame(x = fitted_, y = res_))
-      } else if (inherits(model, "performance_simres")) {
-        return(plot.see_performance_simres(
-          model,
-          linewidth = linewidth,
-          size_point = size_point,
-          alpha = alpha,
-          alpha_dot = alpha_dot,
-          colors = colors,
-          detrend = detrend,
-          base_size = base_size,
-          transform = stats::qnorm,
-          ...
-        ))
-      } else if (is.numeric(model)) {
-        res_ <- sort(model[!is.infinite(model)])
-        dat <- stats::na.omit(data.frame(y = res_))
-      } else {
-        res_ <- sort(stats::rstudent(model), na.last = NA)
-        dat <- stats::na.omit(data.frame(y = res_))
-      }
-
-      .plot_diag_qq(
-        dat,
+  } else if (type == "qq") {
+    # return early for simres
+    if (inherits(model, "performance_simres")) {
+      return(plot.see_performance_simres(
+        model,
+        linewidth = linewidth,
         size_point = size_point,
-        linewidth = linewidth,
-        size_axis_title = size_axis_title,
-        size_title = size_title,
-        base_size = base_size,
-        alpha_level = alpha,
-        detrend = detrend,
+        alpha = alpha,
         alpha_dot = alpha_dot,
-        model_info = model_info,
-        method = method,
-        model_class = class(model)[1]
-      )
-    } else if (type == "density") {
-      if (inherits(model, "performance_simres")) {
-        r <- stats::residuals(model, quantile_function = stats::qnorm)
-        r <- r[!is.infinite(r)]
-      } else if (is.numeric(model)) {
-        r <- model[!is.infinite(model) & !is.na(model)]
-      } else {
-        r <- suppressMessages(stats::residuals(model))
-      }
-      dat <- as.data.frame(bayestestR::estimate_density(r))
-      dat$curve <- stats::dnorm(
-        seq(min(dat$x), max(dat$x), length.out = nrow(dat)),
-        mean(r),
-        stats::sd(r)
-      )
-      .plot_diag_norm(
-        dat,
-        linewidth = linewidth,
-        alpha_level = alpha,
-        base_size = base_size,
-        size_axis_title = size_axis_title,
-        size_title = size_title
-      )
-    } else if (type == "pp") {
-      x <- suppressMessages(sort(stats::residuals(model), na.last = NA))
-      dat <- data.frame(res = x)
-      .plot_diag_pp(
-        dat,
-        size_point = size_point,
-        linewidth = linewidth,
-        base_size = base_size,
-        size_axis_title = size_axis_title,
-        size_title = size_title,
-        alpha_level = alpha,
+        colors = colors,
         detrend = detrend,
-        alpha_dot = alpha_dot,
-        method = method
-      )
+        base_size = base_size,
+        transform = stats::qnorm,
+        ...
+      ))
     }
+
+    model_info <- attributes(x)$model_info
+    dat <- .residuals_qq(model)
+    .plot_diag_qq(
+      dat,
+      size_point = size_point,
+      linewidth = linewidth,
+      size_axis_title = size_axis_title,
+      size_title = size_title,
+      base_size = base_size,
+      alpha_level = alpha,
+      detrend = detrend,
+      alpha_dot = alpha_dot,
+      model_info = model_info,
+      method = method,
+      model_class = class(model)[1]
+    )
+  } else if (type == "density") {
+    dat <- .residuals_density(model)
+    .plot_diag_norm(
+      dat,
+      linewidth = linewidth,
+      alpha_level = alpha,
+      base_size = base_size,
+      size_axis_title = size_axis_title,
+      size_title = size_title
+    )
+  } else if (type == "pp") {
+    dat <- .residuals_pp(model)
+    .plot_diag_pp(
+      dat,
+      size_point = size_point,
+      linewidth = linewidth,
+      base_size = base_size,
+      size_axis_title = size_axis_title,
+      size_title = size_title,
+      alpha_level = alpha,
+      detrend = detrend,
+      alpha_dot = alpha_dot,
+      method = method
+    )
+  }
+}
+
+
+# extract residuals
+
+.residuals_qq <- function(model) {
+  if (inherits(model, c("lme", "lmerMod", "merMod", "afex_aov", "BFBayesFactor"))) {
+    res_ <- suppressMessages(sort(stats::residuals(model), na.last = NA))
+    dat <- stats::na.omit(data.frame(y = res_))
+  } else if (inherits(model, "glmmTMB")) {
+    res_ <- abs(stats::residuals(model, type = "deviance"))
+    dat <- stats::na.omit(data.frame(y = res_))
+  } else if (inherits(model, "glm")) {
+    res_ <- abs(stats::rstandard(model, type = "deviance"))
+    fitted_ <- stats::qnorm(
+      (stats::ppoints(length(res_)) + 1) / 2
+    )[order(order(res_))]
+    dat <- stats::na.omit(data.frame(x = fitted_, y = res_))
+  } else if (.is_efa(model)) {
+    res_ <- suppressMessages(sort(insight::get_residuals(model), na.last = NA))
+    dat <- stats::na.omit(data.frame(y = res_))
+  } else if (is.numeric(model)) {
+    res_ <- sort(model[!is.infinite(model)])
+    dat <- stats::na.omit(data.frame(y = res_))
+  } else {
+    res_ <- sort(stats::rstudent(model), na.last = NA)
+    dat <- stats::na.omit(data.frame(y = res_))
+  }
+  dat
+}
+
+
+.residuals_density <- function(model) {
+  if (inherits(model, "performance_simres")) {
+    r <- stats::residuals(model, quantile_function = stats::qnorm)
+    r <- r[!is.infinite(r)]
+  } else if (is.numeric(model)) {
+    r <- model[!is.infinite(model) & !is.na(model)]
+  } else if (.is_efa(model)) {
+    r <- insight::get_residuals(model)
+  } else {
+    r <- suppressMessages(stats::residuals(model))
+  }
+  dat <- as.data.frame(bayestestR::estimate_density(r))
+  dat$curve <- stats::dnorm(
+    seq(min(dat$x), max(dat$x), length.out = nrow(dat)),
+    mean(r),
+    stats::sd(r)
+  )
+  dat
+}
+
+
+.residuals_pp <- function(model) {
+  if (.is_efa(model)) {
+    x <- suppressMessages(sort(insight::get_residuals(model), na.last = NA))
+  } else {
+    x <- suppressMessages(sort(stats::residuals(model), na.last = NA))
+  }
+  data.frame(res = x)
+}
+
+
+.is_efa <- function(model = NULL, mclass = NULL) {
+  efa_classes <- c("psych", "fa", "principal", "omega", "parameters_efa", "parameters_omega")
+  if (is.null(mclass)) {
+    inherits(model, efa_classes)
+  } else {
+    any(tolower(mclass) %in% efa_classes)
   }
 }
 
 
 # normality plot: density -------------------------
 
-.plot_diag_norm <- function(x,
-                            linewidth,
-                            size_axis_title = 10,
-                            size_title = 12,
-                            alpha_level = 0.2,
-                            theme_style = theme_lucid,
-                            base_size = 10,
-                            colors = unname(social_colors(c("green", "blue", "red")))) {
+.plot_diag_norm <- function(
+  x,
+  linewidth,
+  size_axis_title = 10,
+  size_title = 12,
+  alpha_level = 0.2,
+  theme_style = theme_lucid,
+  base_size = 10,
+  colors = unname(social_colors(c("green", "blue", "red")))
+) {
   ggplot2::ggplot(x, ggplot2::aes(x = .data$x)) +
     ggplot2::geom_ribbon(
       mapping = ggplot2::aes(ymin = 0, ymax = .data$y),
@@ -211,22 +255,36 @@ plot.see_check_normality <- function(x,
 
 # normality plot: QQ -------------------------
 
-.plot_diag_qq <- function(x,
-                          size_point,
-                          linewidth,
-                          size_axis_title = 10,
-                          size_title = 12,
-                          alpha_level = 0.2,
-                          detrend = FALSE,
-                          method = "ell",
-                          theme_style = theme_lucid,
-                          base_size = 10,
-                          colors = unname(social_colors(c("green", "blue", "red"))),
-                          alpha_dot = 0.8,
-                          show_dots = TRUE,
-                          model_info = NULL,
-                          model_class = NULL) {
+.plot_diag_qq <- function(
+  x,
+  size_point,
+  linewidth,
+  size_axis_title = 10,
+  size_title = 12,
+  alpha_level = 0.2,
+  detrend = FALSE,
+  method = "ell",
+  theme_style = theme_lucid,
+  base_size = 10,
+  colors = unname(social_colors(c("green", "blue", "red"))),
+  alpha_dot = 0.8,
+  show_dots = TRUE,
+  model_info = NULL,
+  model_class = NULL
+) {
   qhalfnorm <- function(p) stats::qnorm((p + 1) / 2)
+
+  # set default y-range for FA / PCA
+  if (!is.null(model_class) && .is_efa(model = NULL, mclass = model_class)) {
+    if (any(abs(x$y) > 0.075)) {
+      y_range <- c(-max(abs(x$y)), max(abs(x$y)))
+    } else {
+      y_range <- c(-0.075, 0.075)
+    }
+  } else {
+    y_range <- NULL
+  }
+
   # qq-halfnorm for GLM
   if (isTRUE(model_info$is_binomial) || isTRUE(model_info$is_count)) {
     gg_init <- ggplot2::ggplot(x, ggplot2::aes(x = .data$x, y = .data$y))
@@ -310,16 +368,14 @@ plot.see_check_normality <- function(x,
         stroke = 0,
         size = size_point,
         colour = colors[2]
-      ),
-      if (detrend) {
-        ggplot2::ylim(y_range)
-      }
+      )
     )
 
     if (detrend) {
       y_lab <- "Sample Quantile Deviations"
     } else {
       y_lab <- "Sample Quantiles"
+      y_range <- NULL
     }
   }
 
@@ -327,7 +383,7 @@ plot.see_check_normality <- function(x,
     qq_stuff[2] <- NULL
   }
 
-  gg_init +
+  p <- gg_init +
     qq_stuff +
     ggplot2::labs(
       title = "Normality of Residuals",
@@ -342,33 +398,46 @@ plot.see_check_normality <- function(x,
       plot.title.size = size_title,
       axis.title.size = size_axis_title
     )
+
+  if (!is.null(y_range)) {
+    p <- p + ggplot2::ylim(y_range)
+  }
+
+  p
 }
 
 
 # normality plot: PP -------------------------
 
-.plot_diag_pp <- function(x,
-                          size_point,
-                          linewidth,
-                          size_axis_title = base_size,
-                          size_title = 12,
-                          alpha_level = 0.2,
-                          detrend = FALSE,
-                          method = "ell",
-                          theme_style = theme_lucid,
-                          base_size = 10,
-                          colors = unname(social_colors(c("green", "blue", "red"))),
-                          alpha_dot = 0.8) {
+.plot_diag_pp <- function(
+  x,
+  size_point,
+  linewidth,
+  size_axis_title = base_size,
+  size_title = 12,
+  alpha_level = 0.2,
+  detrend = FALSE,
+  method = "ell",
+  theme_style = theme_lucid,
+  base_size = 10,
+  colors = unname(social_colors(c("green", "blue", "red"))),
+  alpha_dot = 0.8
+) {
   if (requireNamespace("qqplotr", quietly = TRUE)) {
     p_plot <- ggplot2::ggplot(x, ggplot2::aes(sample = .data$res)) +
-      qqplotr::stat_pp_band(alpha = alpha_level, detrend = detrend, bandType = method) +
+      qqplotr::stat_pp_band(
+        alpha = alpha_level,
+        detrend = detrend,
+        bandType = method
+      ) +
       qqplotr::stat_pp_line(
         linewidth = linewidth,
         colour = colors[1],
         detrend = detrend
       ) +
       qqplotr::stat_pp_point(
-        shape = 16, stroke = 0,
+        shape = 16,
+        stroke = 0,
         size = size_point,
         colour = colors[2],
         alpha = alpha_dot,
@@ -394,12 +463,15 @@ plot.see_check_normality <- function(x,
         alpha = alpha_dot
       )
   } else {
-    insight::format_error("Package 'qqplotr' OR 'MASS' required for P-P plots. Please install one of them.")
+    insight::format_error(
+      "Package 'qqplotr' OR 'MASS' required for P-P plots. Please install one of them."
+    )
   }
 
-
   y_lab <- "Sample Cummulative Probability"
-  if (detrend) y_lab <- paste0(y_lab, " Deviations")
+  if (detrend) {
+    y_lab <- paste0(y_lab, " Deviations")
+  }
 
   p_plot +
     ggplot2::labs(
@@ -420,18 +492,20 @@ plot.see_check_normality <- function(x,
 
 # normality plot: Random Effects QQ -------------------------
 
-.plot_diag_reqq <- function(x,
-                            size_point,
-                            linewidth,
-                            size_axis_title = base_size,
-                            size_title = 12,
-                            panel = TRUE,
-                            alpha_level = 0.2,
-                            theme_style = theme_lucid,
-                            base_size = 10,
-                            colors = unname(social_colors(c("green", "blue", "red"))),
-                            alpha_dot = 0.8,
-                            show_dots = TRUE) {
+.plot_diag_reqq <- function(
+  x,
+  size_point,
+  linewidth,
+  size_axis_title = base_size,
+  size_title = 12,
+  panel = TRUE,
+  alpha_level = 0.2,
+  theme_style = theme_lucid,
+  base_size = 10,
+  colors = unname(social_colors(c("green", "blue", "red"))),
+  alpha_dot = 0.8,
+  show_dots = TRUE
+) {
   lapply(names(x), function(i) {
     dat <- x[[i]]
     p <- ggplot2::ggplot(dat, ggplot2::aes(x = .data$x, y = .data$y)) +
@@ -471,7 +545,6 @@ plot.see_check_normality <- function(x,
         )
     }
 
-
     if (nlevels(dat$facet) > 1 && isTRUE(panel)) {
       p <- p + ggplot2::facet_wrap(~facet, scales = "free")
     }
