@@ -42,7 +42,11 @@ data_plot.performance_pp_check <- function(x, type = "density", ...) {
     model_info = attr(x, "model_info")
   )
 
-  class(dataplot) <- unique(c("data_plot", "see_performance_pp_check", class(dataplot)))
+  class(dataplot) <- unique(c(
+    "data_plot",
+    "see_performance_pp_check",
+    class(dataplot)
+  ))
   dataplot
 }
 
@@ -86,25 +90,32 @@ data_plot.performance_pp_check <- function(x, type = "density", ...) {
 #' out <- check_predictions(model)
 #' plot(out, type = "discrete_dots")
 #' @export
-print.see_performance_pp_check <- function(x,
-                                           linewidth = 0.5,
-                                           size_point = 2,
-                                           size_bar = 0.7,
-                                           size_axis_title = base_size,
-                                           size_title = 12,
-                                           base_size = 10,
-                                           alpha_line = 0.15,
-                                           style = theme_lucid,
-                                           colors = unname(social_colors(c("green", "blue"))),
-                                           type = "density",
-                                           x_limits = NULL,
-                                           ...) {
+print.see_performance_pp_check <- function(
+  x,
+  linewidth = 0.5,
+  size_point = 2,
+  size_bar = 0.7,
+  size_axis_title = base_size,
+  size_title = 12,
+  base_size = 10,
+  alpha_line = 0.15,
+  style = theme_lucid,
+  colors = unname(social_colors(c("green", "blue"))),
+  type = "density",
+  x_limits = NULL,
+  ...
+) {
   orig_x <- x
   check_range <- isTRUE(attributes(x)$check_range)
   plot_type <- attributes(x)$type
   is_stan <- attributes(x)$is_stan
 
-  if (missing(type) && !is.null(plot_type) && plot_type %in% c("density", "discrete_dots", "discrete_interval", "discrete_both")) {
+  if (
+    missing(type) &&
+      !is.null(plot_type) &&
+      plot_type %in%
+        c("density", "discrete_dots", "discrete_interval", "discrete_both")
+  ) {
     type <- plot_type
   } else {
     type <- insight::validate_argument(
@@ -146,25 +157,33 @@ print.see_performance_pp_check <- function(x,
 
 #' @rdname print.see_performance_pp_check
 #' @export
-plot.see_performance_pp_check <- function(x,
-                                          linewidth = 0.5,
-                                          size_point = 2,
-                                          size_bar = 0.7,
-                                          size_axis_title = base_size,
-                                          size_title = 12,
-                                          base_size = 10,
-                                          alpha_line = 0.15,
-                                          style = theme_lucid,
-                                          colors = unname(social_colors(c("green", "blue"))),
-                                          type = "density",
-                                          x_limits = NULL,
-                                          ...) {
+plot.see_performance_pp_check <- function(
+  x,
+  linewidth = 0.5,
+  size_point = 2,
+  size_bar = 0.7,
+  size_axis_title = base_size,
+  size_title = 12,
+  base_size = 10,
+  alpha_line = 0.15,
+  style = theme_lucid,
+  colors = unname(social_colors(c("green", "blue"))),
+  type = "density",
+  x_limits = NULL,
+  ...
+) {
   orig_x <- x
   check_range <- isTRUE(attributes(x)$check_range)
   plot_type <- attributes(x)$type
   is_stan <- attributes(x)$is_stan
 
-  if (missing(type) && !is.null(plot_type) && plot_type %in% c("density", "discrete_dots", "discrete_interval", "discrete_both")) { # nolint
+  if (
+    missing(type) &&
+      !is.null(plot_type) &&
+      plot_type %in%
+        c("density", "discrete_dots", "discrete_interval", "discrete_both")
+  ) {
+    # nolint
     type <- plot_type
   } else {
     type <- insight::validate_argument(
@@ -202,25 +221,35 @@ plot.see_performance_pp_check <- function(x,
 }
 
 
-.plot_pp_check <- function(x,
-                           linewidth,
-                           size_point,
-                           alpha_line,
-                           theme_style,
-                           base_size = 10,
-                           size_axis_title = 10,
-                           size_title = 12,
-                           colors,
-                           type = "density",
-                           x_limits = NULL,
-                           is_stan = NULL,
-                           ...) {
+.plot_pp_check <- function(
+  x,
+  linewidth,
+  size_point,
+  alpha_line,
+  theme_style,
+  base_size = 10,
+  size_axis_title = 10,
+  size_title = 12,
+  colors,
+  type = "density",
+  x_limits = NULL,
+  is_stan = NULL,
+  ...
+) {
   info <- attr(x, "info")
 
   # discrete plot type from "bayesplot::pp_check()" returns a different data
   # structure, so we need to handle it differently
   if (isTRUE(is_stan) && type != "density") {
-    return(.plot_check_predictions_stan_dots(x, colors, info, linewidth, size_point, alpha_line, ...))
+    return(.plot_check_predictions_stan_dots(
+      x,
+      colors,
+      info,
+      linewidth,
+      size_point,
+      alpha_line,
+      ...
+    ))
   }
 
   # default bandwidth, for smooting
@@ -230,10 +259,26 @@ plot.see_performance_pp_check <- function(x,
   }
 
   minfo <- info$model_info
-  suggest_dots <- (minfo$is_bernoulli || minfo$is_count || minfo$is_ordinal || minfo$is_categorical)
+  suggest_dots <- (minfo$is_bernoulli ||
+    minfo$is_count ||
+    minfo$is_ordinal ||
+    minfo$is_categorical)
 
-  if (!is.null(type) && type %in% c("discrete_dots", "discrete_interval", "discrete_both") && suggest_dots) {
-    out <- .plot_check_predictions_dots(x, colors, info, linewidth, size_point, alpha_line, type, ...)
+  if (
+    !is.null(type) &&
+      type %in% c("discrete_dots", "discrete_interval", "discrete_both") &&
+      suggest_dots
+  ) {
+    out <- .plot_check_predictions_dots(
+      x,
+      colors,
+      info,
+      linewidth,
+      size_point,
+      alpha_line,
+      type,
+      ...
+    )
   } else {
     if (suggest_dots) {
       insight::format_alert(
@@ -242,27 +287,36 @@ plot.see_performance_pp_check <- function(x,
       )
     }
     # denity plot - for models that have no binary or count/ordinal outcome
-    out <- .plot_check_predictions_density(x, colors, info, linewidth, alpha_line, bandwidth, ...)
+    out <- .plot_check_predictions_density(
+      x,
+      colors,
+      info,
+      linewidth,
+      alpha_line,
+      bandwidth,
+      ...
+    )
   }
 
-
   dots <- list(...)
   if (isTRUE(dots[["check_model"]])) {
-    out <- out + theme_style(
-      base_size = base_size,
-      plot.title.space = 3,
-      axis.title.space = 5,
-      axis.title.size = size_axis_title,
-      plot.title.size = size_title
-    )
+    out <- out +
+      theme_style(
+        base_size = base_size,
+        plot.title.space = 3,
+        axis.title.space = 5,
+        axis.title.size = size_axis_title,
+        plot.title.size = size_title
+      )
   }
 
   if (isTRUE(dots[["adjust_legend"]]) || isTRUE(info$check_range)) {
-    out <- out + ggplot2::theme(
-      legend.position = "bottom",
-      legend.margin = ggplot2::margin(0, 0, 0, 0),
-      legend.box.margin = ggplot2::margin(-5, -5, -5, -5)
-    )
+    out <- out +
+      ggplot2::theme(
+        legend.position = "bottom",
+        legend.margin = ggplot2::margin(0, 0, 0, 0),
+        legend.box.margin = ggplot2::margin(-5, -5, -5, -5)
+      )
   }
 
   if (!is.null(x_limits)) {
@@ -273,13 +327,15 @@ plot.see_performance_pp_check <- function(x,
 }
 
 
-.plot_check_predictions_density <- function(x,
-                                            colors,
-                                            info,
-                                            linewidth,
-                                            alpha_line,
-                                            bandwidth,
-                                            ...) {
+.plot_check_predictions_density <- function(
+  x,
+  colors,
+  info,
+  linewidth,
+  alpha_line,
+  bandwidth,
+  ...
+) {
   ggplot2::ggplot(x) +
     ggplot2::stat_density(
       mapping = ggplot2::aes(
@@ -294,10 +350,12 @@ plot.see_performance_pp_check <- function(x,
       bw = bandwidth
     ) +
     ggplot2::scale_y_continuous() +
-    ggplot2::scale_color_manual(values = c(
-      "Observed data" = colors[1],
-      "Model-predicted data" = colors[2]
-    )) +
+    ggplot2::scale_color_manual(
+      values = c(
+        "Observed data" = colors[1],
+        "Model-predicted data" = colors[2]
+      )
+    ) +
     ggplot2::scale_linewidth_manual(
       values = c(
         "Observed data" = 1.7 * linewidth,
@@ -328,22 +386,32 @@ plot.see_performance_pp_check <- function(x,
 }
 
 
-.plot_check_predictions_dots <- function(x,
-                                         colors,
-                                         info,
-                                         linewidth,
-                                         size_point,
-                                         alpha_line,
-                                         type = "discrete_dots",
-                                         ...) {
+.plot_check_predictions_dots <- function(
+  x,
+  colors,
+  info,
+  linewidth,
+  size_point,
+  alpha_line,
+  type = "discrete_dots",
+  ...
+) {
   # make sure we have a factor, so "table()" generates frequencies for all levels
   # for each group - we need tables of same size to bind data frames
   x$values <- as.factor(x$values)
   x <- stats::aggregate(x["values"], list(grp = x$grp), table)
-  x <- cbind(data.frame(key = "Model-predicted data", stringsAsFactors = FALSE), x)
+  x <- cbind(
+    data.frame(key = "Model-predicted data", stringsAsFactors = FALSE),
+    x
+  )
   x <- cbind(x[1:2], as.data.frame(x[[3]]))
   x$key[nrow(x)] <- "Observed data"
-  x <- datawizard::data_to_long(x, select = -1:-2, names_to = "x", values_to = "count")
+  x <- datawizard::data_to_long(
+    x,
+    select = -1:-2,
+    names_to = "x",
+    values_to = "count"
+  )
   if (insight::n_unique(x$x) > 8) {
     x$x <- datawizard::to_numeric(x$x, dummy_factors = TRUE)
   }
@@ -357,7 +425,11 @@ plot.see_performance_pp_check <- function(x,
         unlist(bayestestR::ci(i)[c("CI_low", "CI_high")])
       )
     }
-    x_errorbars <- stats::aggregate(x["count"], list(x$x), centrality_dispersion)
+    x_errorbars <- stats::aggregate(
+      x["count"],
+      list(x$x),
+      centrality_dispersion
+    )
     x_errorbars <- cbind(x_errorbars[1], as.data.frame(x_errorbars[[2]]))
     colnames(x_errorbars) <- c("x", "count", "CI_low", "CI_high")
     x_errorbars <- cbind(
@@ -406,20 +478,21 @@ plot.see_performance_pp_check <- function(x,
     } else {
       p2 <- p1
     }
-    p2 <- p2 + ggplot2::geom_point(
-      data = x[x$key == "Model-predicted data", ],
-      mapping = ggplot2::aes(
-        x = .data$x,
-        y = .data$count,
-        group = .data$grp,
-        color = .data$key
-      ),
-      alpha = alpha_line,
-      position = ggplot2::position_jitter(width = 0.1, height = 0.02),
-      size = 0.8 * size_point,
-      stroke = 0,
-      shape = 16
-    ) +
+    p2 <- p2 +
+      ggplot2::geom_point(
+        data = x[x$key == "Model-predicted data", ],
+        mapping = ggplot2::aes(
+          x = .data$x,
+          y = .data$count,
+          group = .data$grp,
+          color = .data$key
+        ),
+        alpha = alpha_line,
+        position = ggplot2::position_jitter(width = 0.1, height = 0.02),
+        size = 0.8 * size_point,
+        stroke = 0,
+        shape = 16
+      ) +
       # for legend
       ggplot2::geom_point(
         data = x[x$key == "Observed data", ],
@@ -458,10 +531,12 @@ plot.see_performance_pp_check <- function(x,
 
   p +
     ggplot2::scale_y_continuous() +
-    ggplot2::scale_color_manual(values = c(
-      "Observed data" = colors[1],
-      "Model-predicted data" = colors[2]
-    )) +
+    ggplot2::scale_color_manual(
+      values = c(
+        "Observed data" = colors[1],
+        "Model-predicted data" = colors[2]
+      )
+    ) +
     ggplot2::labs(
       x = info$xlab,
       y = info$ylab,
@@ -478,13 +553,15 @@ plot.see_performance_pp_check <- function(x,
 }
 
 
-.plot_check_predictions_stan_dots <- function(x,
-                                              colors,
-                                              info,
-                                              linewidth,
-                                              size_point,
-                                              alpha_line,
-                                              ...) {
+.plot_check_predictions_stan_dots <- function(
+  x,
+  colors,
+  info,
+  linewidth,
+  size_point,
+  alpha_line,
+  ...
+) {
   # make sure we have a factor, so "table()" generates frequencies for all levels
   # for each group - we need tables of same size to bind data frames
   x$Group[x$Group == "y"] <- "Observed data"
@@ -521,10 +598,12 @@ plot.see_performance_pp_check <- function(x,
       shape = 16
     ) +
     ggplot2::scale_y_continuous() +
-    ggplot2::scale_color_manual(values = c(
-      "Observed data" = colors[1],
-      "Model-predicted data" = colors[2]
-    )) +
+    ggplot2::scale_color_manual(
+      values = c(
+        "Observed data" = colors[1],
+        "Model-predicted data" = colors[2]
+      )
+    ) +
     ggplot2::labs(
       x = info$xlab,
       y = info$ylab,
@@ -543,9 +622,11 @@ plot.see_performance_pp_check <- function(x,
 }
 
 
-.plot_pp_check_range <- function(x,
-                                 size_bar = 0.7,
-                                 colors = unname(social_colors(c("green", "blue")))) {
+.plot_pp_check_range <- function(
+  x,
+  size_bar = 0.7,
+  colors = unname(social_colors(c("green", "blue")))
+) {
   original <- data.frame(
     x = c(min(x$y), max(x$y)),
     group = factor(c("Minimum", "Maximum"), levels = c("Minimum", "Maximum")),
@@ -569,7 +650,10 @@ plot.see_performance_pp_check <- function(x,
   )
   replicated$group <- factor(replicated$group, levels = c("Minimum", "Maximum"))
 
-  p <- ggplot2::ggplot(replicated, ggplot2::aes(x = .data$x, group = .data$group)) +
+  p <- ggplot2::ggplot(
+    replicated,
+    ggplot2::aes(x = .data$x, group = .data$group)
+  ) +
     ggplot2::facet_wrap(~group, scales = "free_x")
 
   if (insight::n_unique(replicated$x) <= 12) {
@@ -577,9 +661,12 @@ plot.see_performance_pp_check <- function(x,
   } else if (.is_integer(replicated$x)) {
     p <- p +
       ggplot2::geom_bar(width = size_bar, fill = colors[2], color = NA) +
-      ggplot2::scale_x_continuous(n.breaks = round(insight::n_unique(replicated$x) / 4))
+      ggplot2::scale_x_continuous(
+        n.breaks = round(insight::n_unique(replicated$x) / 4)
+      )
   } else {
-    p <- p + ggplot2::geom_histogram(binwidth = size_bar, fill = colors[2], color = NA)
+    p <- p +
+      ggplot2::geom_histogram(binwidth = size_bar, fill = colors[2], color = NA)
   }
 
   p +
@@ -590,7 +677,8 @@ plot.see_performance_pp_check <- function(x,
       linewidth = 1
     ) +
     ggplot2::labs(
-      x = NULL, y = NULL,
+      x = NULL,
+      y = NULL,
       subtitle = "Model-predicted extrema should contain observed data extrema"
     )
 }
