@@ -7,13 +7,23 @@ data_plot.estimate_contrasts <- function(x, data = NULL, ...) {
 #' @keywords internal
 .data_plot_estimate_contrasts <- function(x, means = NULL, ...) {
   if (is.null(means)) {
-    stop("Please provide the estimated means data obtained via 'estimate_means()'.", call. = FALSE)
+    stop(
+      "Please provide the estimated means data obtained via 'estimate_means()'.",
+      call. = FALSE
+    )
   } else {
     x_name <- names(means)[1]
   }
 
-  y_name <- c("Median", "Mean", "MAP", "Coefficient")[c("Median", "Mean", "MAP", "Coefficient") %in% names(means)][1]
-  dataplot <- .data_contrasts_and_means(x, means, x_name = x_name, y_name = y_name)
+  y_name <- c("Median", "Mean", "MAP", "Coefficient")[
+    c("Median", "Mean", "MAP", "Coefficient") %in% names(means)
+  ][1]
+  dataplot <- .data_contrasts_and_means(
+    x,
+    means,
+    x_name = x_name,
+    y_name = y_name
+  )
 
   attr(dataplot, "info") <- list(
     xlab = x_name,
@@ -44,8 +54,14 @@ data_plot.estimate_contrasts <- function(x, data = NULL, ...) {
 
   polygons <- rbind(
     cbind(polygons, data.frame(x = polygons$Level1, y = polygons$Mean1)),
-    cbind(polygons, data.frame(x = polygons$Level2, y = polygons$Mean1 - polygons$CI_low)),
-    cbind(polygons, data.frame(x = polygons$Level2, y = polygons$Mean1 - polygons$CI_high))
+    cbind(
+      polygons,
+      data.frame(x = polygons$Level2, y = polygons$Mean1 - polygons$CI_low)
+    ),
+    cbind(
+      polygons,
+      data.frame(x = polygons$Level2, y = polygons$Mean1 - polygons$CI_high)
+    )
   )
 
   list(
