@@ -1,9 +1,11 @@
 #' @export
-data_plot.p_significance <- function(x,
-                                     data = NULL,
-                                     grid = TRUE,
-                                     show_intercept = FALSE,
-                                     ...) {
+data_plot.p_significance <- function(
+  x,
+  data = NULL,
+  grid = TRUE,
+  show_intercept = FALSE,
+  ...
+) {
   if (is.null(data)) {
     data <- .retrieve_data(x)
   }
@@ -12,7 +14,10 @@ data_plot.p_significance <- function(x,
 
   if (inherits(data, "emmGrid")) {
     insight::check_if_installed("emmeans")
-    data <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(data, names = FALSE)))
+    data <- as.data.frame(as.matrix(emmeans::as.mcmc.emmGrid(
+      data,
+      names = FALSE
+    )))
   } else if (inherits(data, c("stanreg", "brmsfit"))) {
     params <- insight::clean_parameters(data)
     data <- as.data.frame(data, optional = FALSE)
@@ -34,13 +39,21 @@ data_plot.p_significance <- function(x,
       if (is.null(params) || !all(c("Effects", "Component") %in% colnames(params))) {
         dataplot <- rbind(
           dataplot,
-          .compute_densities_ps(data[[i]], name = i, threshold = attr(x, "threshold"))
+          .compute_densities_ps(
+            data[[i]],
+            name = i,
+            threshold = attr(x, "threshold")
+          )
         )
       } else {
         dataplot <- rbind(
           dataplot,
           cbind(
-            .compute_densities_ps(data[[i]], name = i, threshold = attr(x, "threshold")),
+            .compute_densities_ps(
+              data[[i]],
+              name = i,
+              threshold = attr(x, "threshold")
+            ),
             Effects = params$Effects[params$Parameter == i],
             Component = params$Component[params$Parameter == i]
           )
@@ -49,25 +62,44 @@ data_plot.p_significance <- function(x,
     }
 
     if ("Effects" %in% names(dataplot) && "Component" %in% names(dataplot)) {
-      if (length(unique(dataplot$Effects)) == 1 && length(unique(dataplot$Component)) == 1) {
+      if (
+        length(unique(dataplot$Effects)) == 1 &&
+          length(unique(dataplot$Component)) == 1
+      ) {
         dataplot$Effects <- NULL
         dataplot$Component <- NULL
       } else {
         if (is.factor(dataplot$Effects)) {
-          dataplot$Effects <- factor(dataplot$Effects, levels = sort(levels(dataplot$Effects)))
+          dataplot$Effects <- factor(
+            dataplot$Effects,
+            levels = sort(levels(dataplot$Effects))
+          )
         } else {
-          dataplot$Effects <- factor(dataplot$Effects, levels = unique(dataplot$Effects))
+          dataplot$Effects <- factor(
+            dataplot$Effects,
+            levels = unique(dataplot$Effects)
+          )
         }
         if (is.factor(dataplot$Component)) {
-          dataplot$Component <- factor(dataplot$Component, levels = sort(levels(dataplot$Component)))
+          dataplot$Component <- factor(
+            dataplot$Component,
+            levels = sort(levels(dataplot$Component))
+          )
         } else {
-          dataplot$Component <- factor(dataplot$Component, levels = unique(dataplot$Component))
+          dataplot$Component <- factor(
+            dataplot$Component,
+            levels = unique(dataplot$Component)
+          )
         }
       }
     }
   } else {
     levels_order <- NULL
-    dataplot <- .compute_densities_ps(data[, 1], name = "Posterior", threshold = attr(x, "threshold"))
+    dataplot <- .compute_densities_ps(
+      data[, 1],
+      name = "Posterior",
+      threshold = attr(x, "threshold")
+    )
   }
 
   dataplot <- do.call(
@@ -92,7 +124,10 @@ data_plot.p_significance <- function(x,
       }
     )
   )
-  dataplot$fill2 <- with(dataplot, ifelse(prop >= 0.5, "Most probable", "Less probable"))
+  dataplot$fill2 <- with(
+    dataplot,
+    ifelse(prop >= 0.5, "Most probable", "Less probable")
+  )
   dataplot <- dataplot[, which(!names(dataplot) %in% c("n", "prop"))]
 
   if (!is.null(levels_order)) {
@@ -150,15 +185,25 @@ data_plot.p_significance <- function(x,
 
   out$fill <- "Less Probable"
   out$fill[out$x > threshold[1] & out$x < threshold[2]] <- "ROPE"
-  out$fill[out$x > threshold[2]] <- ifelse(fifty_cents, "Significant", "Less Probable")
-  out$fill[out$x < threshold[1]] <- ifelse(fifty_cents, "Less Probable", "Significant")
+  out$fill[out$x > threshold[2]] <- ifelse(
+    fifty_cents,
+    "Significant",
+    "Less Probable"
+  )
+  out$fill[out$x < threshold[1]] <- ifelse(
+    fifty_cents,
+    "Less Probable",
+    "Significant"
+  )
 
   out$height <- out$y
   out$y <- name
 
   # normalize
   range_diff <- diff(range(out$height, na.rm = TRUE), na.rm = TRUE)
-  out$height <- as.vector((out$height - min(out$height, na.rm = TRUE)) / range_diff)
+  out$height <- as.vector(
+    (out$height - min(out$height, na.rm = TRUE)) / range_diff
+  )
   out
 }
 
@@ -185,13 +230,15 @@ data_plot.p_significance <- function(x,
 #' plot(result)
 #'
 #' @export
-plot.see_p_significance <- function(x,
-                                    data = NULL,
-                                    show_intercept = FALSE,
-                                    priors = FALSE,
-                                    alpha_priors = 0.4,
-                                    n_columns = 1,
-                                    ...) {
+plot.see_p_significance <- function(
+  x,
+  data = NULL,
+  show_intercept = FALSE,
+  priors = FALSE,
+  alpha_priors = 0.4,
+  n_columns = 1,
+  ...
+) {
   # save model for later use
   model <- .retrieve_data(x)
 
@@ -245,17 +292,16 @@ plot.see_p_significance <- function(x,
     geom_vline(aes(xintercept = 0), linetype = "dotted") +
     guides(fill = "none", color = "none", group = "none")
 
-
   if (length(unique(x$y)) == 1L && is.numeric(x$y)) {
     p <- p + scale_y_continuous(breaks = NULL, labels = NULL)
   } else {
     p <- p + scale_y_discrete(labels = axis_labels)
   }
 
-
   if (!is.null(n_columns)) {
     if ("Component" %in% names(x) && "Effects" %in% names(x)) {
-      p <- p + facet_wrap(~ Effects + Component, scales = "free", ncol = n_columns)
+      p <- p +
+        facet_wrap(~ Effects + Component, scales = "free", ncol = n_columns)
     } else if ("Effects" %in% names(x)) {
       p <- p + facet_wrap(~Effects, scales = "free", ncol = n_columns)
     } else if ("Component" %in% names(x)) {
