@@ -1,12 +1,16 @@
 # TODO: retire in favor of {datawizard}?
 
 #' @keywords internal
-.reshape_to_long <- function(x,
-                             names_to = "group",
-                             values_to = "values",
-                             columns = colnames(x),
-                             id = "id") {
-  if (is.numeric(columns)) columns <- colnames(x)[columns]
+.reshape_to_long <- function(
+  x,
+  names_to = "group",
+  values_to = "values",
+  columns = colnames(x),
+  id = "id"
+) {
+  if (is.numeric(columns)) {
+    columns <- colnames(x)[columns]
+  }
   dat <- stats::reshape(
     as.data.frame(x),
     idvar = id,
