@@ -27,11 +27,13 @@
 #'   theme_modern() +
 #'   scale_color_social(discrete = FALSE)
 #' @export
-scale_color_social <- function(palette = NULL,
-                               discrete = TRUE,
-                               reverse = FALSE,
-                               aesthetics = "color",
-                               ...) {
+scale_color_social <- function(
+  palette = NULL,
+  discrete = TRUE,
+  reverse = FALSE,
+  aesthetics = "color",
+  ...
+) {
   if (is.null(palette)) {
     if (discrete) {
       palette <- "contrast"
@@ -52,17 +54,40 @@ scale_color_social <- function(palette = NULL,
 
 # Aliases -----------------------------------------------------------------
 
-
 #' @rdname scale_color_social
 #' @export
-scale_color_social_d <- function(palette = NULL, discrete = TRUE, reverse = FALSE, aesthetics = "color", ...) {
-  scale_color_social(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_color_social_d <- function(
+  palette = NULL,
+  discrete = TRUE,
+  reverse = FALSE,
+  aesthetics = "color",
+  ...
+) {
+  scale_color_social(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 #' @rdname scale_color_social
 #' @export
-scale_color_social_c <- function(palette = NULL, discrete = FALSE, reverse = FALSE, aesthetics = "color", ...) {
-  scale_color_social(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_color_social_c <- function(
+  palette = NULL,
+  discrete = FALSE,
+  reverse = FALSE,
+  aesthetics = "color",
+  ...
+) {
+  scale_color_social(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 #' @rdname scale_color_social
@@ -80,10 +105,15 @@ scale_colour_social_d <- scale_color_social_d
 
 # Fill --------------------------------------------------------------------
 
-
 #' @rdname scale_color_social
 #' @export
-scale_fill_social <- function(palette = NULL, discrete = TRUE, reverse = FALSE, aesthetics = "fill", ...) {
+scale_fill_social <- function(
+  palette = NULL,
+  discrete = TRUE,
+  reverse = FALSE,
+  aesthetics = "fill",
+  ...
+) {
   if (is.null(palette)) {
     if (discrete) {
       palette <- "contrast"
@@ -104,20 +134,43 @@ scale_fill_social <- function(palette = NULL, discrete = TRUE, reverse = FALSE,
 
 #' @rdname scale_color_social
 #' @export
-scale_fill_social_d <- function(palette = NULL, discrete = TRUE, reverse = FALSE, aesthetics = "fill", ...) {
-  scale_fill_social(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_fill_social_d <- function(
+  palette = NULL,
+  discrete = TRUE,
+  reverse = FALSE,
+  aesthetics = "fill",
+  ...
+) {
+  scale_fill_social(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 #' @rdname scale_color_social
 #' @export
-scale_fill_social_c <- function(palette = NULL, discrete = FALSE, reverse = FALSE, aesthetics = "fill", ...) {
-  scale_fill_social(palette = palette, discrete = discrete, reverse = reverse, aesthetics = aesthetics, ...)
+scale_fill_social_c <- function(
+  palette = NULL,
+  discrete = FALSE,
+  reverse = FALSE,
+  aesthetics = "fill",
+  ...
+) {
+  scale_fill_social(
+    palette = palette,
+    discrete = discrete,
+    reverse = reverse,
+    aesthetics = aesthetics,
+    ...
+  )
 }
 
 
 # Palette --------------------------------------------------------------------
 
-
 # The palette based on flat design colors: https://www.materialui.co/socialcolors
 social_colors_list <- c(
   red = "#cd201f",
@@ -181,7 +234,13 @@ social_palettes <- list(
     "red"
   ),
   contrast = social_colors("blue", "green", "amber", "purple", "red"),
-  light = material_colors("light blue", "purple", "yellow", "light green", "deep orange"),
+  light = material_colors(
+    "light blue",
+    "purple",
+    "yellow",
+    "light green",
+    "deep orange"
+  ),
   complement = social_colors(
     "blue grey",
     "blue",
