@@ -14,23 +14,26 @@
 #'   scale_color_metro() +
 #'   theme_lucid()
 #' @export
-theme_lucid <- function(base_size = 11,
-                        base_family = "",
-                        plot.title.size = 1.1 * base_size,
-                        plot.title.face = "plain",
-                        plot.title.space = 1.35 * base_size,
-                        plot.title.position = "plot",
-                        legend.position = "right",
-                        axis.title.space = 0.9 * base_size,
-                        legend.title.size = base_size,
-                        legend.text.size = 0.9 * base_size,
-                        axis.title.size = base_size,
-                        axis.title.face = "plain",
-                        axis.text.size = 0.9 * base_size,
-                        axis.text.angle = NULL,
-                        tags.size = base_size,
-                        tags.face = "plain",
-                        ...) {
+theme_lucid <- function(
+  base_size = 11,
+  base_family = "",
+  plot.title.size = 1.1 * base_size,
+  plot.title.face = "plain",
+  plot.title.space = 1.35 * base_size,
+  plot.title.position = "plot",
+  legend.position = "right",
+  axis.title.space = 0.9 * base_size,
+  axis.text.space = base_size,
+  legend.title.size = base_size,
+  legend.text.size = 0.9 * base_size,
+  axis.title.size = base_size,
+  axis.title.face = "plain",
+  axis.text.size = 0.9 * base_size,
+  axis.text.angle = NULL,
+  tags.size = base_size,
+  tags.face = "plain",
+  ...
+) {
   theme_modern(
     base_size = base_size,
     base_family = base_family,
@@ -40,6 +43,7 @@ theme_lucid <- function(base_size = 11,
     plot.title.position = plot.title.position,
     legend.position = legend.position,
     axis.title.space = axis.title.space,
+    axis.text.space = axis.text.space,
     legend.title.size = legend.title.size,
     legend.text.size = legend.text.size,
     axis.title.size = axis.title.size,
