@@ -4,12 +4,15 @@ test_that("`plot.see_performance_roc()` works", {
   folds <- sample(nrow(iris), size = nrow(iris) / 8, replace = FALSE)
   test_data <- iris[folds, ]
   train_data <- iris[-folds, ]
-  model <- glm(
+  model <- stats::glm(
     y ~ Sepal.Length + Sepal.Width,
     data = train_data,
     family = "binomial"
   )
   result <- performance::performance_roc(model, new_data = test_data)
 
-  expect_s3_class(plot(result), "gg")
+  vdiffr::expect_doppelganger(
+    title = "plot.see_performance_roc() works",
+    fig = plot(result)
+  )
 })
